==> statehub-0.6.5.crate: statehub-0.6.5/src/statehub/azure.rs <==
//
// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
// Use is subject to license terms.
//

use serde::{Deserialize, Serialize};
use structopt::StructOpt;

#[derive(Clone, Debug, Default, Serialize, Deserialize, PartialEq, StructOpt)]
#[serde(rename_all = "UPPERCASE")]
pub(crate) struct AzureCredentials {
    // #[structopt(help = "Azure Tenant ID", long, requires_all = &["azure_client_id", "azure_client_secret"])]
    #[structopt(help = "Azure Tenant ID", long)]
    azure_tenant_id: Option<String>,
    // #[structopt(help = "Azure Client ID", long, requires_all = &["azure_tenant_id", "azure_client_secret"])]
    #[structopt(help = "Azure Client ID", long)]
    azure_client_id: Option<String>,
    // #[structopt(help = "Azure Client Secret", long, requires_all = &["azure_tenant_id", "azure_client_id"])]
    #[structopt(help = "Azure Client Secret", long)]
    azure_client_secret: Option<String>,
}

impl AzureCredentials {
    pub(crate) fn validate(&self) -> anyhow::Result<()> {
        let all = self.azure_tenant_id.is_some()
            && self.azure_client_id.is_some()
            && self.azure_client_secret.is_some();

        let nothing = self.azure_tenant_id.is_none()
            && self.azure_client_id.is_none()
            && self.azure_client_secret.is_none();

        if all || nothing {
            Ok(())
        } else {
            Err(anyhow::anyhow!(
                "Either all of '{}', '{}' and '{}' options must be set or none of them",
                "azure-tenant-id",
                "azure-client-id",
                "azure-client-secret"
            ))
        }
    }
}

#[cfg(test)]
mod tests {
    use serde_json as json;

    use super::*;

    #[test]
    fn deserialize() {
        let azure = AzureCredentials::default();

        let azure = json::to_value(azure).unwrap();
        assert!(azure.is_object());
        assert!(azure.get("AZURE_TENANT_ID").is_some());
        assert!(azure.get("AZURE_CLIENT_ID").is_some());
        assert!(azure.get("AZURE_CLIENT_SECRET").is_some());
        assert!(azure.get("azure_client_secret").is_none());
    }
}

==> statehub-0.8.2.crate: statehub-0.8.2/src/statehub/azure.rs <==
//
// Copyright (c) 2021 RepliXio Ltd. All rights reserved.
// Use is subject to license terms.
//

use serde::{Deserialize, Serialize};
use serde_with::skip_serializing_none;
use structopt::StructOpt;

#[skip_serializing_none]
#[derive(Clone, Debug, Serialize, Deserialize, PartialEq, StructOpt)]
#[serde(rename_all = "UPPERCASE")]
pub(crate) struct AzureCredentials {
    // #[structopt(help = "Azure Tenant ID", long, requires_all = &["azure_client_id", "azure_client_secret"])]
    #[structopt(help = "Azure Tenant ID", long)]
    azure_tenant_id: Option<String>,
    // #[structopt(help = "Azure Client ID", long, requires_all = &["azure_tenant_id", "azure_client_secret"])]
    #[structopt(help = "Azure Client ID", long)]
    azure_client_id: Option<String>,
    // #[structopt(help = "Azure Client Secret", long, requires_all = &["azure_tenant_id", "azure_client_id"])]
    #[structopt(help = "Azure Client Secret", long)]
    azure_client_secret: Option<String>,
}

impl AzureCredentials {
    pub(crate) fn validate(&self) -> anyhow::Result<()> {
        let all = self.azure_tenant_id.is_some()
            && self.azure_client_id.is_some()
            && self.azure_client_secret.is_some();

        let nothing = self.azure_tenant_id.is_none()
            && self.azure_client_id.is_none()
            && self.azure_client_secret.is_none();

        if all || nothing {
            Ok(())
        } else {
            Err(anyhow::anyhow!(
                "Either all of '{}', '{}' and '{}' options must be set or none of them",
                "azure-tenant-id",
                "azure-client-id",
                "azure-client-secret"
            ))
        }
    }
}

#[cfg(test)]
mod tests {
    use serde_json as json;

    use super::*;

    #[test]
    fn deserialize() {
        let azure = AzureCredentials {
            azure_tenant_id: String::new().into(),
            azure_client_id: String::new().into(),
            azure_client_secret: String::new().into(),
        };

        let azure = json::to_value(azure).unwrap();
        assert!(azure.is_object());
        assert!(azure.get("AZURE_TENANT_ID").is_some());
        assert!(azure.get("AZURE_CLIENT_ID").is_some());
        assert!(azure.get("AZURE_CLIENT_SECRET").is_some());
        assert!(azure.get("azure_client_secret").is_none());
    }
}
